aboutsummaryrefslogtreecommitdiffhomepage
path: root/tools
diff options
context:
space:
mode:
authorGravatar borenet <borenet@google.com>2014-10-17 12:15:46 -0700
committerGravatar Commit bot <commit-bot@chromium.org>2014-10-17 12:15:46 -0700
commit783991585be67da3286680d850a99c5410885965 (patch)
treede13674e938d1f997e5e88397111765b2d035d4e /tools
parent2813f344921f05f634e54646bfc6b971b1a15fd3 (diff)
Fix recreate_skps?
run_measurement was removed in https://codereview.chromium.org/655563007. Based on the comments, I think the right thing to do is replace it with run_benchmark. Hopefully this fixes the bot. BUG=skia: TBR=rmistry NOTRY=true Review URL: https://codereview.chromium.org/658513004
Diffstat (limited to 'tools')
-rw-r--r--tools/skp/webpages_playback.py12
1 files changed, 6 insertions, 6 deletions
diff --git a/tools/skp/webpages_playback.py b/tools/skp/webpages_playback.py
index 50d8932713..4dfe6fca9a 100644
--- a/tools/skp/webpages_playback.py
+++ b/tools/skp/webpages_playback.py
@@ -91,7 +91,7 @@ DEVICE_TO_PLATFORM_PREFIX = {
# How many times the record_wpr binary should be retried.
RETRY_RECORD_WPR_COUNT = 5
# How many times the run_measurement binary should be retried.
RETRY_RUN_MEASUREMENT_COUNT = 5
X11_DISPLAY = os.getenv('DISPLAY', ':0')
@@ -204,10 +204,10 @@ class SkPicturePlayback(object):
self._DownloadWebpagesArchive(wpr_data_file, page_set_basename)
page_set_name = os.path.basename(page_set).split('.')[0]
- run_measurement_cmd = (
+ run_benchmark_cmd = (
'DISPLAY=%s' % X11_DISPLAY,
'timeout', '300',
- os.path.join(self._telemetry_binaries_dir, 'run_measurement'),
+ os.path.join(self._telemetry_binaries_dir, 'run_benchmark'),
'--extra-browser-args=--disable-setuid-sandbox',
'--browser=exact',
'--browser-executable=%s' % self._browser_executable,
@@ -240,7 +240,7 @@ class SkPicturePlayback(object):
for _ in range(RETRY_RUN_MEASUREMENT_COUNT):
try:
print '\n\n=======Capturing SKP of %s=======\n\n' % page_set
- shell_utils.run(' '.join(run_measurement_cmd), shell=True)
+ shell_utils.run(' '.join(run_benchmark_cmd), shell=True)
except shell_utils.CommandFailedException:
# skpicture_printer sometimes fails with AssertionError but the
# captured SKP is still valid. This is a known issue.
@@ -272,9 +272,9 @@ class SkPicturePlayback(object):
os.remove(page_set_dst)
os.remove(wpr_dst)
os.remove(json_dst)
# If we get here then run_measurement did not succeed and thus did not
# break out of the loop.
- raise Exception('run_measurement failed for page_set: %s' % page_set)
+ raise Exception('run_benchmark failed for page_set: %s' % page_set)
if copied_page_set:
os.remove(page_set_dst)
@@ -91,7 +91,7 @@ DEVICE_TO_PLATFORM_PREFIX = {
# How many times the record_wpr binary should be retried.
RETRY_RECORD_WPR_COUNT = 5
-# How many times the run_measurement binary should be retried.
+# How many times the run_benchmark binary should be retried.
RETRY_RUN_MEASUREMENT_COUNT = 5
X11_DISPLAY = os.getenv('DISPLAY', ':0')
@@ -272,9 +272,9 @@ class SkPicturePlayback(object):
os.remove(wpr_dst)
os.remove(json_dst)
- # If we get here then run_measurement did not succeed and thus did not
+ # If we get here then run_benchmark did not succeed and thus did not
# break out of the loop.